pub struct NativeConformanceExecutor { /* private fields */ }Expand description
Native conformance executor using reqwest
Implementations
Sourceimpl NativeConformanceExecutor
impl NativeConformanceExecutor
Sourcepub fn new(config: ConformanceConfig) -> Result<Self>
pub fn new(config: ConformanceConfig) -> Result<Self>
Create a new executor from a ConformanceConfig
Sourcepub fn with_reference_checks(self) -> Self
pub fn with_reference_checks(self) -> Self
Populate checks from hardcoded reference endpoints (/conformance/*).
Used when no --spec is provided.
Sourcepub fn with_spec_driven_checks(self, operations: &[AnnotatedOperation]) -> Self
pub fn with_spec_driven_checks(self, operations: &[AnnotatedOperation]) -> Self
Populate checks from annotated spec operations (spec-driven mode)
Sourcepub fn with_custom_checks(self) -> Result<Self>
pub fn with_custom_checks(self) -> Result<Self>
Load custom checks from the configured YAML file
Sourcepub fn check_count(&self) -> usize
pub fn check_count(&self) -> usize
Return the number of checks that will be executed
Sourcepub async fn execute(&self) -> Result<ConformanceReport>
pub async fn execute(&self) -> Result<ConformanceReport>
Execute all checks and return a ConformanceReport
Sourcepub async fn execute_with_progress(
&self,
tx: Sender<ConformanceProgress>,
) -> Result<ConformanceReport>
pub async fn execute_with_progress( &self, tx: Sender<ConformanceProgress>, ) -> Result<ConformanceReport>
Execute all checks with progress events sent to the channel